<template>
    <section class="game">
        <div class="spinner-border" v-if="isLoading">
            <span class="sr-only">Loading...</span>
        </div>
        <div class="casino-play__wrapper-place" v-else>
            <div class="casino-play__controls" style="width: 100%;">
                <div class="casino-play__control casino-play__control_change" @click="iframeAction(1)">
                    <span>Назад</span>
                </div>
                <div role="button" class="casino-play__control casino-play__control_fullscreen" @click="iframeAction(2)">
                    <img src="/assets/img/fullscreen.svg" alt="Полноэкранный режим" />
                </div>
                <div class="casino-play__control casino-play__control_externa" @click="iframeAction(3)">
                    <img src="/assets/img/external.svg" alt="Открыть игру в новом окне" />
                </div>
                <div class="casino-play__control casino-play__control_refresh" @click="iframeAction(4)">
                    <img src="/assets/img/refresh.svg" alt="Перезагрузить игру" />
                </div>
            </div>
            <fullscreen v-model="fullscreen" ref="fullscreen" class="container">
                <iframe 
                    :src="gameUrl" 
                    scrolling="no" 
                    frameborder="0" 
                    webkitAllowFullScreen="true" 
                    allowfullscreen="true" 
                    mozallowfullscreen="true" 
                />
            </fullscreen>
        </div>
    </section>
</template>

<script>
export default {
    data() {
        return {
            isLoading: true,
            fullscreen: false,
            gameUrl: ''
        }
    },
    methods: {
        getGame() {
            this.$root.axios.post('/slots/getUrl', {
                gameId: this.$route.params.gameId
            })
            .then(response => {
                const {data} = response;

                if(data.error) {
                    this.$router.push({name: 'slots'});
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                this.gameUrl = data.url;
                this.isLoading = false;
            })
        },
        iframeAction(type) {
            if(type == 1) {
                this.$router.push({name: 'slots'});
            } else if(type == 2) {
                this.fullscreen = !this.fullscreen
            } else if(type == 3) {
                window.open(this.gameUrl);
            } else if(type == 4) {
                document.getElementsByTagName("iframe")[0].src = this.gameUrl;
            }
        },
    },
    mounted() {
        this.getGame()
    }
}
</script>

<style scoped>
.game {
    display: -webkit-flex;
    display: flex;
    width: 100%;
    -webkit-align-items: stretch;
    align-items: stretch;
    position: relative
}

.game-component {
    -webkit-align-items: stretch;
    align-items: stretch;
    width: 100%;
    position: relative
}

.casino-play__wrapper-place {
    position: relative;
    width: 100%;
    padding-top: 56.5%;
    margin-top: 42px;
    border-radius: 6px;
    box-shadow: 0 0 50px rgb(143 157 174 / 20%);
    background-color: #fff;
    transition: 0s!important;
}

.casino-play__wrapper-place iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    border-radius: 6px;
    overflow: hidden;
}

.casino-play__controls {
    position: absolute;
    top: -42px;
    right: 0;
    display: flex;
    align-items: center;
}

.casino-play__control {
    display: flex;
    align-items: center;
    justify-content: center;
    width: 36px;
    height: 36px;
    background: #4e6588;
    border-radius: 7px;
    cursor: pointer;
}

.casino-play__control+.casino-play__control {
    margin-left: 5px;
}

.casino-play__control_change {
    width: 100px;
    margin-right: auto;
}

.casino-play__control > img {
    width: 18px;
    height: 18px;
    transition: filter .2s ease-in-out;
}

.casino-play__control_change>span {
    font-size: 16px;
    font-weight: 700;
    margin-bottom: -1px;
    color: #fff;
    text-transform: uppercase;
    transition: color .2s ease-in-out;
}

.game-block, .game-component {
    background: none;
}
.spinner-border {
    display: inline-block;
    width: 2rem;
    height: 2rem;
    vertical-align: text-bottom;
    border: .25em solid currentColor;
    border-right-color: currentcolor;
    border-right-color: transparent;
    border-radius: 50%;
    animation: spinner-border .75s linear infinite;
}

@keyframes spinner-border {
    to {
        transform: rotate(360deg)
    }
}
</style>